@@ -23,6 +23,7 @@ use crate::utils::error_util::ToResult;
 use crate::utils::string_util;
 use crate::wrapper::Wrapper;
 use std::fmt::{Debug, Formatter};
+use crate::snowflake::new_snowflake_id;
 
 /// rbatis engine
 // #[derive(Debug)]
@@ -44,10 +45,10 @@ pub struct Rbatis {
 impl Debug for Rbatis {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         f.debug_struct("Rbatis")
-            .field("pool",&self.pool)
-            .field("page_plugin",&self.page_plugin)
-            .field("sql_intercepts",&self.sql_intercepts)
-            .field("logic_plugin",&self.logic_plugin)
+            .field("pool", &self.pool)
+            .field("page_plugin", &self.page_plugin)
+            .field("sql_intercepts", &self.sql_intercepts)
+            .field("logic_plugin", &self.logic_plugin)
             .finish()
     }
 }
@@ -97,7 +98,7 @@ impl Rbatis {
             sql_intercepts: option.sql_intercepts,
             logic_plugin: option.logic_plugin,
             log_plugin: option.log_plugin,
-            encoder: |q,arg|{
+            encoder: |q, arg| {
                 q.bind_value(arg)?;
                 Ok(())
             },
@@ -213,6 +214,7 @@ impl Rbatis {
         let pool = self.get_pool()?;
         let conn = pool.begin().await?;
         return Ok(RBatisTxExecutor {
+            tx_id: new_snowflake_id(),
             conn: conn,
             rb: &self,
         });
@@ -231,3 +233,31 @@ impl Rbatis {
         self.into()
     }
 }
+
+
+pub trait AsSqlTag {
+    fn sql_tag(&self) -> char;
+    fn do_replace_tag(&self, sql: &mut String);
+}
+
+impl AsSqlTag for DriverType {
+    #[inline]
+    fn sql_tag(&self) -> char {
+        match self {
+            DriverType::None => { '?' }
+            DriverType::Mysql => { '?' }
+            DriverType::Sqlite => { '?' }
+            DriverType::Postgres => { '$' }
+            //mssql is '@p',so use '$' to '@p'
+            DriverType::Mssql => { '$' }
+        }
+    }
+    #[inline]
+    fn do_replace_tag(&self, sql: &mut String) {
+        if self.eq(&DriverType::Mssql) {
+            *sql = sql.replace("$", "@p");
+        }
+    }
+}
+
+
